@@ -50,7 +50,7 @@ pub struct ActivityManager {
 
 impl ActivityManager {
     /// Initializes a new Activity Manager
-    pub fn new(ticks: Duration) -> Result<ActivityManager, HostError> {
+    pub fn new(ticks: Duration, keyring: bool) -> Result<ActivityManager, HostError> {
         // Prepare Context
         // Initialize configuration client
         let (config_client, error_config): (ConfigClient, Option<String>) =
@@ -61,7 +61,7 @@ impl ActivityManager {
                     (ConfigClient::degraded(), Some(err))
                 }
             };
-        let (bookmarks_client, error_bookmark) = match Self::init_bookmarks_client() {
+        let (bookmarks_client, error_bookmark) = match Self::init_bookmarks_client(keyring) {
             Ok(cli) => (cli, None),
             Err(err) => (None, Some(err)),
         };
@@ -90,13 +90,18 @@ impl ActivityManager {
                 )),
                 host_params.password.as_deref(),
             ),
-            Remote::None => self.set_host_params(
-                HostParams::HostBridge(HostBridgeParams::Localhost(
-                    env::current_dir()
-                        .map_err(|e| format!("Could not get current directory: {e}"))?,
-                )),
-                None,
-            ),
+            Remote::None => {
+                // local dir is remote_args.local_dir if set, otherwise current dir
+                let local_dir = remote_args
+                    .local_dir
+                    .unwrap_or_else(|| env::current_dir().unwrap());
+                debug!("host bridge is None, setting local dir to {:?}", local_dir,);
+
+                self.set_host_params(
+                    HostParams::HostBridge(HostBridgeParams::Localhost(local_dir)),
+                    None,
+                )
+            }
         }?;
 
         // set remote
@@ -243,7 +248,7 @@ impl ActivityManager {
                 None => {
                     return Err(format!(
                         r#"Could not resolve bookmark name: "{bookmark_name}" no such bookmark"#
-                    ))
+                    ));
                 }
                 Some(params) => params,
             };
@@ -342,7 +347,7 @@ impl ActivityManager {
     fn run_filetransfer(&mut self) -> Option<NextActivity> {
         info!("Starting FileTransferActivity");
         // Get context
-        let ctx: Context = match self.context.take() {
+        let mut ctx: Context = match self.context.take() {
             Some(ctx) => ctx,
             None => {
                 error!("Failed to start FileTransferActivity: context is None");
@@ -367,8 +372,18 @@ impl ActivityManager {
             }
         };
 
-        let mut activity: FileTransferActivity =
-            FileTransferActivity::new(host_bridge_params, remote_params, self.ticks);
+        // try to setup activity
+        let mut activity =
+            match FileTransferActivity::new(host_bridge_params, remote_params, self.ticks) {
+                Ok(activity) => activity,
+                Err(err) => {
+                    error!("Failed to start FileTransferActivity: {}", err);
+                    ctx.set_error(err);
+                    self.context = Some(ctx);
+                    // Return to authentication
+                    return Some(NextActivity::Authentication);
+                }
+            };
         // Prepare result
         let result: Option<NextActivity>;
         // Create activity
@@ -432,7 +447,7 @@ impl ActivityManager {
 
     // -- misc
 
-    fn init_bookmarks_client() -> Result<Option<BookmarksClient>, String> {
+    fn init_bookmarks_client(keyring: bool) -> Result<Option<BookmarksClient>, String> {
         // Get config dir
         match environment::init_config_dir() {
             Ok(path) => {
@@ -441,16 +456,21 @@ impl ActivityManager {
                     let bookmarks_file: PathBuf =
                         environment::get_bookmarks_paths(config_dir_path.as_path());
                     // Initialize client
-                    BookmarksClient::new(bookmarks_file.as_path(), config_dir_path.as_path(), 16)
-                        .map(Option::Some)
-                        .map_err(|e| {
-                            format!(
-                                "Could not initialize bookmarks (at \"{}\", \"{}\"): {}",
-                                bookmarks_file.display(),
-                                config_dir_path.display(),
-                                e
-                            )
-                        })
+                    BookmarksClient::new(
+                        bookmarks_file.as_path(),
+                        config_dir_path.as_path(),
+                        16,
+                        keyring,
+                    )
+                    .map(Option::Some)
+                    .map_err(|e| {
+                        format!(
+                            "Could not initialize bookmarks (at \"{}\", \"{}\"): {}",
+                            bookmarks_file.display(),
+                            config_dir_path.display(),
+                            e
+                        )
+                    })
                 } else {
                     Ok(None)
                 }
@@ -495,19 +515,28 @@ impl ActivityManager {
                         match ThemeProvider::new(theme_path.as_path()) {
                             Ok(provider) => provider,
                             Err(err) => {
-                                error!("Could not initialize theme provider with file '{}': {}; using theme provider in degraded mode", theme_path.display(), err);
+                                error!(
+                                    "Could not initialize theme provider with file '{}': {}; using theme provider in degraded mode",
+                                    theme_path.display(),
+                                    err
+                                );
                                 ThemeProvider::degraded()
                             }
                         }
                     }
                     None => {
-                        error!("This system doesn't provide a configuration directory; using theme provider in degraded mode");
+                        error!(
+                            "This system doesn't provide a configuration directory; using theme provider in degraded mode"
+                        );
                         ThemeProvider::degraded()
                     }
                 }
             }
             Err(err) => {
-                error!("Could not initialize configuration directory: {}; using theme provider in degraded mode", err);
+                error!(
+                    "Could not initialize configuration directory: {}; using theme provider in degraded mode",
+                    err
+                );
                 ThemeProvider::degraded()
             }
         }
