@@ -9,7 +9,7 @@ pub struct SmbParams {
     pub workgroup: Option<String>,
 }
 
-#[cfg(unix)]
+#[cfg(posix)]
 impl From<TransferSmbParams> for SmbParams {
     fn from(params: TransferSmbParams) -> Self {
         Self {
@@ -19,7 +19,7 @@ impl From<TransferSmbParams> for SmbParams {
     }
 }
 
-#[cfg(windows)]
+#[cfg(win)]
 impl From<TransferSmbParams> for SmbParams {
     fn from(params: TransferSmbParams) -> Self {
         Self {
