@@ -12,14 +12,14 @@ use tuirealm::ratatui::widgets::Clear;
 use tuirealm::{State, StateValue, Sub, SubClause, SubEventClause};
 
 use super::{
-    components, AuthActivity, AuthFormId, Context, FileTransferProtocol, FormTab,
-    HostBridgeProtocol, Id, InputMask,
+    AuthActivity, AuthFormId, Context, FileTransferProtocol, FormTab, HostBridgeProtocol, Id,
+    InputMask, components,
 };
+use crate::filetransfer::FileTransferParams;
 use crate::filetransfer::params::{
     AwsS3Params, GenericProtocolParams, KubeProtocolParams, ProtocolParams, SmbParams,
     WebDAVProtocolParams,
 };
-use crate::filetransfer::FileTransferParams;
 use crate::utils::ui::{Popup, Size};
 
 impl AuthActivity {
@@ -28,23 +28,26 @@ impl AuthActivity {
         let key_color = self.theme().misc_keys;
         let info_color = self.theme().misc_info_dialog;
         // Headers
-        assert!(self
-            .app
-            .mount(Id::Title, Box::<components::Title>::default(), vec![])
-            .is_ok());
-        assert!(self
-            .app
-            .mount(Id::Subtitle, Box::<components::Subtitle>::default(), vec![])
-            .is_ok());
+        assert!(
+            self.app
+                .mount(Id::Title, Box::<components::Title>::default(), vec![])
+                .is_ok()
+        );
+        assert!(
+            self.app
+                .mount(Id::Subtitle, Box::<components::Subtitle>::default(), vec![])
+                .is_ok()
+        );
         // Footer
-        assert!(self
-            .app
-            .mount(
-                Id::HelpFooter,
-                Box::new(components::HelpFooter::new(key_color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .mount(
+                    Id::HelpFooter,
+                    Box::new(components::HelpFooter::new(key_color)),
+                    vec![]
+                )
+                .is_ok()
+        );
 
         // Host bridge auth form
         self.mount_host_bridge_protocol(HostBridgeProtocol::Localhost);
@@ -113,17 +116,18 @@ impl AuthActivity {
             .get_string(super::STORE_KEY_LATEST_VERSION)
         {
             let version: String = version.to_string();
-            assert!(self
-                .app
-                .mount(
-                    Id::NewVersionDisclaimer,
-                    Box::new(components::NewVersionDisclaimer::new(
-                        version.as_str(),
-                        info_color
-                    )),
-                    vec![]
-                )
-                .is_ok());
+            assert!(
+                self.app
+                    .mount(
+                        Id::NewVersionDisclaimer,
+                        Box::new(components::NewVersionDisclaimer::new(
+                            version.as_str(),
+                            info_color
+                        )),
+                        vec![]
+                    )
+                    .is_ok()
+            );
         }
         // Load bookmarks
         self.view_bookmarks();
@@ -455,14 +459,15 @@ impl AuthActivity {
             })
             .collect();
         let bookmarks_color = self.theme().auth_bookmarks;
-        assert!(self
-            .app
-            .remount(
-                Id::BookmarksList,
-                Box::new(components::BookmarksList::new(&bookmarks, bookmarks_color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::BookmarksList,
+                    Box::new(components::BookmarksList::new(&bookmarks, bookmarks_color)),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     /// View recent connections
@@ -473,14 +478,15 @@ impl AuthActivity {
             .map(|x| Self::fmt_recent(self.bookmarks_client().unwrap().get_recent(x).unwrap()))
             .collect();
         let recents_color = self.theme().auth_recents;
-        assert!(self
-            .app
-            .remount(
-                Id::RecentsList,
-                Box::new(components::RecentsList::new(&bookmarks, recents_color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::RecentsList,
+                    Box::new(components::RecentsList::new(&bookmarks, recents_color)),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     // -- mount
@@ -488,14 +494,15 @@ impl AuthActivity {
     /// Mount error box
     pub(super) fn mount_error<S: AsRef<str>>(&mut self, text: S) {
         let err_color = self.theme().misc_error_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::ErrorPopup,
-                Box::new(components::ErrorPopup::new(text, err_color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::ErrorPopup,
+                    Box::new(components::ErrorPopup::new(text, err_color)),
+                    vec![]
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::ErrorPopup).is_ok());
     }
 
@@ -507,14 +514,15 @@ impl AuthActivity {
     /// Mount info box
     pub(super) fn mount_info<S: AsRef<str>>(&mut self, text: S) {
         let color = self.theme().misc_info_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::InfoPopup,
-                Box::new(components::InfoPopup::new(text, color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::InfoPopup,
+                    Box::new(components::InfoPopup::new(text, color)),
+                    vec![]
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::InfoPopup).is_ok());
     }
 
@@ -526,14 +534,15 @@ impl AuthActivity {
     /// Mount wait box
     pub(super) fn mount_wait(&mut self, text: &str) {
         let wait_color = self.theme().misc_info_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::WaitPopup,
-                Box::new(components::WaitPopup::new(text, wait_color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::WaitPopup,
+                    Box::new(components::WaitPopup::new(text, wait_color)),
+                    vec![]
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::WaitPopup).is_ok());
     }
 
@@ -545,14 +554,15 @@ impl AuthActivity {
     /// Mount size error
     pub(super) fn mount_size_err(&mut self) {
         // Mount
-        assert!(self
-            .app
-            .remount(
-                Id::WindowSizeError,
-                Box::new(components::WindowSizeError::new(Color::Red)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::WindowSizeError,
+                    Box::new(components::WindowSizeError::new(Color::Red)),
+                    vec![]
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::WindowSizeError).is_ok());
     }
 
@@ -565,14 +575,15 @@ impl AuthActivity {
     pub(super) fn mount_quit(&mut self) {
         // Protocol
         let quit_color = self.theme().misc_quit_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::QuitPopup,
-                Box::new(components::QuitPopup::new(quit_color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::QuitPopup,
+                    Box::new(components::QuitPopup::new(quit_color)),
+                    vec![]
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::QuitPopup).is_ok());
     }
 
@@ -584,14 +595,15 @@ impl AuthActivity {
     /// Mount bookmark delete dialog
     pub(super) fn mount_bookmark_del_dialog(&mut self) {
         let warn_color = self.theme().misc_warn_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::DeleteBookmarkPopup,
-                Box::new(components::DeleteBookmarkPopup::new(warn_color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::DeleteBookmarkPopup,
+                    Box::new(components::DeleteBookmarkPopup::new(warn_color)),
+                    vec![]
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::DeleteBookmarkPopup).is_ok());
     }
 
@@ -603,14 +615,15 @@ impl AuthActivity {
     /// Mount recent delete dialog
     pub(super) fn mount_recent_del_dialog(&mut self) {
         let warn_color = self.theme().misc_warn_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::DeleteRecentPopup,
-                Box::new(components::DeleteRecentPopup::new(warn_color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::DeleteRecentPopup,
+                    Box::new(components::DeleteRecentPopup::new(warn_color)),
+                    vec![]
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::DeleteRecentPopup).is_ok());
     }
 
@@ -623,22 +636,24 @@ impl AuthActivity {
     pub(super) fn mount_bookmark_save_dialog(&mut self, form_tab: FormTab) {
         let save_color = self.theme().misc_save_dialog;
         let warn_color = self.theme().misc_warn_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::BookmarkName,
-                Box::new(components::BookmarkName::new(form_tab, save_color)),
-                vec![]
-            )
-            .is_ok());
-        assert!(self
-            .app
-            .remount(
-                Id::BookmarkSavePassword,
-                Box::new(components::BookmarkSavePassword::new(form_tab, warn_color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::BookmarkName,
+                    Box::new(components::BookmarkName::new(form_tab, save_color)),
+                    vec![]
+                )
+                .is_ok()
+        );
+        assert!(
+            self.app
+                .remount(
+                    Id::BookmarkSavePassword,
+                    Box::new(components::BookmarkSavePassword::new(form_tab, warn_color)),
+                    vec![]
+                )
+                .is_ok()
+        );
         // Give focus to input bookmark name
         assert!(self.app.active(&Id::BookmarkName).is_ok());
     }
@@ -652,14 +667,15 @@ impl AuthActivity {
     /// Mount keybindings
     pub(super) fn mount_keybindings(&mut self) {
         let key_color = self.theme().misc_keys;
-        assert!(self
-            .app
-            .remount(
-                Id::Keybindings,
-                Box::new(components::Keybindings::new(key_color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::Keybindings,
+                    Box::new(components::Keybindings::new(key_color)),
+                    vec![]
+                )
+                .is_ok()
+        );
         // Active help
         assert!(self.app.active(&Id::Keybindings).is_ok());
     }
@@ -675,22 +691,24 @@ impl AuthActivity {
             if let Some(release_notes) = ctx.store().get_string(super::STORE_KEY_RELEASE_NOTES) {
                 // make spans
                 let info_color = self.theme().misc_info_dialog;
-                assert!(self
-                    .app
-                    .remount(
-                        Id::NewVersionChangelog,
-                        Box::new(components::ReleaseNotes::new(release_notes, info_color)),
-                        vec![]
-                    )
-                    .is_ok());
-                assert!(self
-                    .app
-                    .remount(
-                        Id::InstallUpdatePopup,
-                        Box::new(components::InstallUpdatePopup::new(info_color)),
-                        vec![]
-                    )
-                    .is_ok());
+                assert!(
+                    self.app
+                        .remount(
+                            Id::NewVersionChangelog,
+                            Box::new(components::ReleaseNotes::new(release_notes, info_color)),
+                            vec![]
+                        )
+                        .is_ok()
+                );
+                assert!(
+                    self.app
+                        .remount(
+                            Id::InstallUpdatePopup,
+                            Box::new(components::InstallUpdatePopup::new(info_color)),
+                            vec![]
+                        )
+                        .is_ok()
+                );
                 assert!(self.app.active(&Id::InstallUpdatePopup).is_ok());
             }
         }
@@ -704,32 +722,34 @@ impl AuthActivity {
 
     pub(super) fn mount_host_bridge_protocol(&mut self, protocol: HostBridgeProtocol) {
         let protocol_color = self.theme().auth_protocol;
-        assert!(self
-            .app
-            .remount(
-                Id::HostBridge(AuthFormId::Protocol),
-                Box::new(components::HostBridgeProtocolRadio::new(
-                    protocol,
-                    protocol_color
-                )),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::HostBridge(AuthFormId::Protocol),
+                    Box::new(components::HostBridgeProtocolRadio::new(
+                        protocol,
+                        protocol_color
+                    )),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn mount_remote_protocol(&mut self, protocol: FileTransferProtocol) {
         let protocol_color = self.theme().auth_protocol;
-        assert!(self
-            .app
-            .remount(
-                Id::Remote(AuthFormId::Protocol),
-                Box::new(components::RemoteProtocolRadio::new(
-                    protocol,
-                    protocol_color
-                )),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::Remote(AuthFormId::Protocol),
+                    Box::new(components::RemoteProtocolRadio::new(
+                        protocol,
+                        protocol_color
+                    )),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn mount_remote_directory<S: AsRef<str>>(
@@ -739,18 +759,19 @@ impl AuthActivity {
     ) {
         let id = Self::form_tab_id(form_tab, AuthFormId::RemoteDirectory);
         let protocol_color = self.theme().auth_protocol;
-        assert!(self
-            .app
-            .remount(
-                id,
-                Box::new(components::InputRemoteDirectory::new(
-                    remote_path.as_ref(),
-                    form_tab,
-                    protocol_color
-                )),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    id,
+                    Box::new(components::InputRemoteDirectory::new(
+                        remote_path.as_ref(),
+                        form_tab,
+                        protocol_color
+                    )),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn mount_local_directory<S: AsRef<str>>(
@@ -760,315 +781,337 @@ impl AuthActivity {
     ) {
         let id = Self::form_tab_id(form_tab, AuthFormId::LocalDirectory);
         let color = self.theme().auth_username;
-        assert!(self
-            .app
-            .remount(
-                id,
-                Box::new(components::InputLocalDirectory::new(
-                    local_path.as_ref(),
-                    form_tab,
-                    color
-                )),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    id,
+                    Box::new(components::InputLocalDirectory::new(
+                        local_path.as_ref(),
+                        form_tab,
+                        color
+                    )),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn mount_address(&mut self, form_tab: FormTab, address: &str) {
         let addr_color = self.theme().auth_address;
         let id = Self::form_tab_id(form_tab, AuthFormId::Address);
-        assert!(self
-            .app
-            .remount(
-                id,
-                Box::new(components::InputAddress::new(address, form_tab, addr_color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    id,
+                    Box::new(components::InputAddress::new(address, form_tab, addr_color)),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn mount_port(&mut self, form_tab: FormTab, port: u16) {
         let port_color = self.theme().auth_port;
         let id = Self::form_tab_id(form_tab, AuthFormId::Port);
-        assert!(self
-            .app
-            .remount(
-                id,
-                Box::new(components::InputPort::new(port, form_tab, port_color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    id,
+                    Box::new(components::InputPort::new(port, form_tab, port_color)),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn mount_username(&mut self, form_tab: FormTab, username: &str) {
         let username_color = self.theme().auth_username;
         let id = Self::form_tab_id(form_tab, AuthFormId::Username);
-        assert!(self
-            .app
-            .remount(
-                id,
-                Box::new(components::InputUsername::new(
-                    username,
-                    form_tab,
-                    username_color
-                )),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    id,
+                    Box::new(components::InputUsername::new(
+                        username,
+                        form_tab,
+                        username_color
+                    )),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn mount_password(&mut self, form_tab: FormTab, password: &str) {
         let password_color = self.theme().auth_password;
         let id = Self::form_tab_id(form_tab, AuthFormId::Password);
-        assert!(self
-            .app
-            .remount(
-                id,
-                Box::new(components::InputPassword::new(
-                    password,
-                    form_tab,
-                    password_color
-                )),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    id,
+                    Box::new(components::InputPassword::new(
+                        password,
+                        form_tab,
+                        password_color
+                    )),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn mount_s3_bucket(&mut self, form_tab: FormTab, bucket: &str) {
         let addr_color = self.theme().auth_address;
         let id = Self::form_tab_id(form_tab, AuthFormId::S3Bucket);
-        assert!(self
-            .app
-            .remount(
-                id,
-                Box::new(components::InputS3Bucket::new(bucket, form_tab, addr_color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    id,
+                    Box::new(components::InputS3Bucket::new(bucket, form_tab, addr_color)),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn mount_s3_region(&mut self, form_tab: FormTab, region: &str) {
         let port_color = self.theme().auth_port;
         let id = Self::form_tab_id(form_tab, AuthFormId::S3Region);
-        assert!(self
-            .app
-            .remount(
-                id,
-                Box::new(components::InputS3Region::new(region, form_tab, port_color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    id,
+                    Box::new(components::InputS3Region::new(region, form_tab, port_color)),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn mount_s3_endpoint(&mut self, form_tab: FormTab, endpoint: &str) {
         let username_color = self.theme().auth_username;
         let id = Self::form_tab_id(form_tab, AuthFormId::S3Endpoint);
-        assert!(self
-            .app
-            .remount(
-                id,
-                Box::new(components::InputS3Endpoint::new(
-                    endpoint,
-                    form_tab,
-                    username_color
-                )),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    id,
+                    Box::new(components::InputS3Endpoint::new(
+                        endpoint,
+                        form_tab,
+                        username_color
+                    )),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn mount_s3_profile(&mut self, form_tab: FormTab, profile: &str) {
         let color = self.theme().auth_password;
         let id = Self::form_tab_id(form_tab, AuthFormId::S3Profile);
-        assert!(self
-            .app
-            .remount(
-                id,
-                Box::new(components::InputS3Profile::new(profile, form_tab, color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    id,
+                    Box::new(components::InputS3Profile::new(profile, form_tab, color)),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn mount_s3_access_key(&mut self, form_tab: FormTab, key: &str) {
         let color = self.theme().auth_address;
         let id = Self::form_tab_id(form_tab, AuthFormId::S3AccessKey);
-        assert!(self
-            .app
-            .remount(
-                id,
-                Box::new(components::InputS3AccessKey::new(key, form_tab, color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    id,
+                    Box::new(components::InputS3AccessKey::new(key, form_tab, color)),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn mount_s3_secret_access_key(&mut self, form_tab: FormTab, key: &str) {
         let color = self.theme().auth_port;
         let id = Self::form_tab_id(form_tab, AuthFormId::S3SecretAccessKey);
-        assert!(self
-            .app
-            .remount(
-                id,
-                Box::new(components::InputS3SecretAccessKey::new(
-                    key, form_tab, color
-                )),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    id,
+                    Box::new(components::InputS3SecretAccessKey::new(
+                        key, form_tab, color
+                    )),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn mount_s3_security_token(&mut self, form_tab: FormTab, token: &str) {
         let color = self.theme().auth_username;
         let id = Self::form_tab_id(form_tab, AuthFormId::S3SecurityToken);
-        assert!(self
-            .app
-            .remount(
-                id,
-                Box::new(components::InputS3SecurityToken::new(
-                    token, form_tab, color
-                )),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    id,
+                    Box::new(components::InputS3SecurityToken::new(
+                        token, form_tab, color
+                    )),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn mount_s3_session_token(&mut self, form_tab: FormTab, token: &str) {
         let color = self.theme().auth_password;
         let id = Self::form_tab_id(form_tab, AuthFormId::S3SessionToken);
-        assert!(self
-            .app
-            .remount(
-                id,
-                Box::new(components::InputS3SessionToken::new(token, form_tab, color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    id,
+                    Box::new(components::InputS3SessionToken::new(token, form_tab, color)),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn mount_s3_new_path_style(&mut self, form_tab: FormTab, new_path_style: bool) {
         let color = self.theme().auth_address;
         let id = Self::form_tab_id(form_tab, AuthFormId::S3NewPathStyle);
-        assert!(self
-            .app
-            .remount(
-                id,
-                Box::new(components::RadioS3NewPathStyle::new(
-                    new_path_style,
-                    form_tab,
-                    color
-                )),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    id,
+                    Box::new(components::RadioS3NewPathStyle::new(
+                        new_path_style,
+                        form_tab,
+                        color
+                    )),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn mount_kube_namespace(&mut self, form_tab: FormTab, value: &str) {
         let color = self.theme().auth_port;
         let id = Self::form_tab_id(form_tab, AuthFormId::KubeNamespace);
-        assert!(self
-            .app
-            .remount(
-                id,
-                Box::new(components::InputKubeNamespace::new(value, form_tab, color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    id,
+                    Box::new(components::InputKubeNamespace::new(value, form_tab, color)),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn mount_kube_cluster_url(&mut self, form_tab: FormTab, value: &str) {
         let color = self.theme().auth_username;
         let id = Self::form_tab_id(form_tab, AuthFormId::KubeClusterUrl);
-        assert!(self
-            .app
-            .remount(
-                id,
-                Box::new(components::InputKubeClusterUrl::new(value, form_tab, color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    id,
+                    Box::new(components::InputKubeClusterUrl::new(value, form_tab, color)),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn mount_kube_username(&mut self, form_tab: FormTab, value: &str) {
         let color = self.theme().auth_password;
         let id = Self::form_tab_id(form_tab, AuthFormId::KubeUsername);
-        assert!(self
-            .app
-            .remount(
-                id,
-                Box::new(components::InputKubeUsername::new(value, form_tab, color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    id,
+                    Box::new(components::InputKubeUsername::new(value, form_tab, color)),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn mount_kube_client_cert(&mut self, form_tab: FormTab, value: &str) {
         let color = self.theme().auth_address;
         let id = Self::form_tab_id(form_tab, AuthFormId::KubeClientCert);
-        assert!(self
-            .app
-            .remount(
-                id,
-                Box::new(components::InputKubeClientCert::new(value, form_tab, color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    id,
+                    Box::new(components::InputKubeClientCert::new(value, form_tab, color)),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn mount_kube_client_key(&mut self, form_tab: FormTab, value: &str) {
         let color = self.theme().auth_port;
         let id = Self::form_tab_id(form_tab, AuthFormId::KubeClientKey);
-        assert!(self
-            .app
-            .remount(
-                id,
-                Box::new(components::InputKubeClientKey::new(value, form_tab, color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    id,
+                    Box::new(components::InputKubeClientKey::new(value, form_tab, color)),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn mount_smb_share(&mut self, form_tab: FormTab, share: &str) {
         let color = self.theme().auth_password;
         let id = Self::form_tab_id(form_tab, AuthFormId::SmbShare);
 
-        assert!(self
-            .app
-            .remount(
-                id,
-                Box::new(components::InputSmbShare::new(share, form_tab, color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    id,
+                    Box::new(components::InputSmbShare::new(share, form_tab, color)),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     #[cfg(posix)]
     pub(super) fn mount_smb_workgroup(&mut self, form_tab: FormTab, workgroup: &str) {
         let color = self.theme().auth_address;
         let id = Self::form_tab_id(form_tab, AuthFormId::SmbWorkgroup);
-        assert!(self
-            .app
-            .remount(
-                id,
-                Box::new(components::InputSmbWorkgroup::new(
-                    workgroup, form_tab, color
-                )),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    id,
+                    Box::new(components::InputSmbWorkgroup::new(
+                        workgroup, form_tab, color
+                    )),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn mount_webdav_uri(&mut self, form_tab: FormTab, uri: &str) {
         let addr_color = self.theme().auth_address;
         let id = Self::form_tab_id(form_tab, AuthFormId::WebDAVUri);
-        assert!(self
-            .app
-            .remount(
-                id,
-                Box::new(components::InputWebDAVUri::new(uri, form_tab, addr_color)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    id,
+                    Box::new(components::InputWebDAVUri::new(uri, form_tab, addr_color)),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     fn form_tab_id(form_tab: FormTab, id: AuthFormId) -> Id {
@@ -1949,65 +1992,66 @@ impl AuthActivity {
 
     fn init_global_listener(&mut self) {
         use tuirealm::event::{Key, KeyEvent, KeyModifiers};
-        assert!(self
-            .app
-            .mount(
-                Id::GlobalListener,
-                Box::<components::GlobalListener>::default(),
-                vec![
-                    Sub::new(
-                        SubEventClause::Keyboard(KeyEvent {
-                            code: Key::Esc,
-                            modifiers: KeyModifiers::NONE,
-                        }),
-                        Self::no_popup_mounted_clause(),
-                    ),
-                    Sub::new(
-                        SubEventClause::Keyboard(KeyEvent {
-                            code: Key::Function(10),
-                            modifiers: KeyModifiers::NONE,
-                        }),
-                        Self::no_popup_mounted_clause(),
-                    ),
-                    Sub::new(
-                        SubEventClause::Keyboard(KeyEvent {
-                            code: Key::Char('c'),
-                            modifiers: KeyModifiers::CONTROL,
-                        }),
-                        Self::no_popup_mounted_clause(),
-                    ),
-                    Sub::new(
-                        SubEventClause::Keyboard(KeyEvent {
-                            code: Key::Char('h'),
-                            modifiers: KeyModifiers::CONTROL,
-                        }),
-                        Self::no_popup_mounted_clause(),
-                    ),
-                    Sub::new(
-                        SubEventClause::Keyboard(KeyEvent {
-                            code: Key::Function(1),
-                            modifiers: KeyModifiers::NONE,
-                        }),
-                        Self::no_popup_mounted_clause(),
-                    ),
-                    Sub::new(
-                        SubEventClause::Keyboard(KeyEvent {
-                            code: Key::Char('r'),
-                            modifiers: KeyModifiers::CONTROL,
-                        }),
-                        Self::no_popup_mounted_clause(),
-                    ),
-                    Sub::new(
-                        SubEventClause::Keyboard(KeyEvent {
-                            code: Key::Char('s'),
-                            modifiers: KeyModifiers::CONTROL,
-                        }),
-                        Self::no_popup_mounted_clause(),
-                    ),
-                    Sub::new(SubEventClause::WindowResize, SubClause::Always)
-                ]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .mount(
+                    Id::GlobalListener,
+                    Box::<components::GlobalListener>::default(),
+                    vec![
+                        Sub::new(
+                            SubEventClause::Keyboard(KeyEvent {
+                                code: Key::Esc,
+                                modifiers: KeyModifiers::NONE,
+                            }),
+                            Self::no_popup_mounted_clause(),
+                        ),
+                        Sub::new(
+                            SubEventClause::Keyboard(KeyEvent {
+                                code: Key::Function(10),
+                                modifiers: KeyModifiers::NONE,
+                            }),
+                            Self::no_popup_mounted_clause(),
+                        ),
+                        Sub::new(
+                            SubEventClause::Keyboard(KeyEvent {
+                                code: Key::Char('c'),
+                                modifiers: KeyModifiers::CONTROL,
+                            }),
+                            Self::no_popup_mounted_clause(),
+                        ),
+                        Sub::new(
+                            SubEventClause::Keyboard(KeyEvent {
+                                code: Key::Char('h'),
+                                modifiers: KeyModifiers::CONTROL,
+                            }),
+                            Self::no_popup_mounted_clause(),
+                        ),
+                        Sub::new(
+                            SubEventClause::Keyboard(KeyEvent {
+                                code: Key::Function(1),
+                                modifiers: KeyModifiers::NONE,
+                            }),
+                            Self::no_popup_mounted_clause(),
+                        ),
+                        Sub::new(
+                            SubEventClause::Keyboard(KeyEvent {
+                                code: Key::Char('r'),
+                                modifiers: KeyModifiers::CONTROL,
+                            }),
+                            Self::no_popup_mounted_clause(),
+                        ),
+                        Sub::new(
+                            SubEventClause::Keyboard(KeyEvent {
+                                code: Key::Char('s'),
+                                modifiers: KeyModifiers::CONTROL,
+                            }),
+                            Self::no_popup_mounted_clause(),
+                        ),
+                        Sub::new(SubEventClause::WindowResize, SubClause::Always)
+                    ]
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn get_current_form_tab(&self) -> FormTab {
