@@ -7,8 +7,8 @@ use std::io::Read;
 use std::path::{Path, PathBuf};
 use std::time::SystemTime;
 
-use remotefs::fs::Metadata;
 use remotefs::File;
+use remotefs::fs::Metadata;
 
 use super::{FileTransferActivity, LogLevel, SelectedFile, TransferPayload};
 
@@ -16,7 +16,7 @@ impl FileTransferActivity {
     pub(crate) fn action_edit_local_file(&mut self) {
         let entries: Vec<File> = match self.get_local_selected_entries() {
             SelectedFile::One(entry) => vec![entry],
-            SelectedFile::Many(entries) => entries,
+            SelectedFile::Many(entries) => entries.into_iter().map(|(f, _)| f).collect(),
             SelectedFile::None => vec![],
         };
         // Edit all entries
@@ -38,12 +38,16 @@ impl FileTransferActivity {
                 }
             }
         }
+
+        // clear selection
+        self.host_bridge_mut().clear_queue();
+        self.reload_host_bridge_filelist();
     }
 
     pub(crate) fn action_edit_remote_file(&mut self) {
         let entries: Vec<File> = match self.get_remote_selected_entries() {
             SelectedFile::One(entry) => vec![entry],
-            SelectedFile::Many(entries) => entries,
+            SelectedFile::Many(entries) => entries.into_iter().map(|(f, _)| f).collect(),
             SelectedFile::None => vec![],
         };
         // Edit all entries
@@ -60,6 +64,10 @@ impl FileTransferActivity {
                 }
             }
         }
+
+        // clear selection
+        self.remote_mut().clear_queue();
+        self.reload_remote_filelist();
     }
 
     /// Edit a file on localhost
@@ -221,10 +229,7 @@ impl FileTransferActivity {
     /// Edit file on remote host
     fn edit_remote_file(&mut self, file: File) -> Result<(), String> {
         // Create temp file
-        let tmpfile: PathBuf = match self.download_file_as_temp(&file) {
-            Ok(p) => p,
-            Err(err) => return Err(err),
-        };
+        let tmpfile = self.download_file_as_temp(&file)?;
         // Download file
         let file_name = file.name();
         let file_path = file.path().to_path_buf();
@@ -243,7 +248,7 @@ impl FileTransferActivity {
                     "Could not stat \"{}\": {}",
                     tmpfile.as_path().display(),
                     err
-                ))
+                ));
             }
         };
         // Edit file
@@ -256,7 +261,7 @@ impl FileTransferActivity {
                     "Could not stat \"{}\": {}",
                     tmpfile.as_path().display(),
                     err
-                ))
+                ));
             }
         };
         // Check if file has changed
@@ -282,7 +287,7 @@ impl FileTransferActivity {
                             "Could not stat \"{}\": {}",
                             tmpfile.as_path().display(),
                             err
-                        ))
+                        ));
                     }
                 };
                 // Send file
