@@ -214,7 +214,7 @@ impl DeletePopup {
                         .modifiers(BorderType::Rounded),
                 )
                 .foreground(color)
-                .choices(&["Yes", "No"])
+                .choices(["Yes", "No"])
                 .value(1)
                 .title("Delete file(s)?", Alignment::Center),
         }
@@ -279,7 +279,7 @@ impl DisconnectPopup {
                         .modifiers(BorderType::Rounded),
                 )
                 .foreground(color)
-                .choices(&["Yes", "No"])
+                .choices(["Yes", "No"])
                 .title("Are you sure you want to disconnect?", Alignment::Center),
         }
     }
@@ -344,7 +344,7 @@ impl ErrorPopup {
                         .modifiers(BorderType::Rounded),
                 )
                 .foreground(color)
-                .text(&[TextSpan::from(text.as_ref())])
+                .text([TextSpan::from(text.as_ref())])
                 .wrap(true),
         }
     }
@@ -362,89 +362,6 @@ impl Component<Msg, NoUserEvent> for ErrorPopup {
     }
 }
 
-#[derive(MockComponent)]
-pub struct ExecPopup {
-    component: Input,
-}
-
-impl ExecPopup {
-    pub fn new(color: Color) -> Self {
-        Self {
-            component: Input::default()
-                .borders(
-                    Borders::default()
-                        .color(color)
-                        .modifiers(BorderType::Rounded),
-                )
-                .foreground(color)
-                .input_type(InputType::Text)
-                .placeholder("ps a", Style::default().fg(Color::Rgb(128, 128, 128)))
-                .title("Execute command", Alignment::Center),
-        }
-    }
-}
-
-impl Component<Msg, NoUserEvent> for ExecPopup {
-    fn on(&mut self, ev: Event<NoUserEvent>) -> Option<Msg> {
-        match ev {
-            Event::Keyboard(KeyEvent {
-                code: Key::Left, ..
-            }) => {
-                self.perform(Cmd::Move(Direction::Left));
-                Some(Msg::None)
-            }
-            Event::Keyboard(KeyEvent {
-                code: Key::Right, ..
-            }) => {
-                self.perform(Cmd::Move(Direction::Right));
-                Some(Msg::None)
-            }
-            Event::Keyboard(KeyEvent {
-                code: Key::Home, ..
-            }) => {
-                self.perform(Cmd::GoTo(Position::Begin));
-                Some(Msg::None)
-            }
-            Event::Keyboard(KeyEvent { code: Key::End, .. }) => {
-                self.perform(Cmd::GoTo(Position::End));
-                Some(Msg::None)
-            }
-            Event::Keyboard(KeyEvent {
-                code: Key::Delete, ..
-            }) => {
-                self.perform(Cmd::Cancel);
-                Some(Msg::None)
-            }
-            Event::Keyboard(KeyEvent {
-                code: Key::Backspace,
-                ..
-            }) => {
-                self.perform(Cmd::Delete);
-                Some(Msg::None)
-            }
-            Event::Keyboard(KeyEvent {
-                code: Key::Char(ch),
-                ..
-            }) => {
-                self.perform(Cmd::Type(ch));
-                Some(Msg::None)
-            }
-            Event::Keyboard(KeyEvent {
-                code: Key::Enter, ..
-            }) => match self.state() {
-                State::One(StateValue::String(i)) => {
-                    Some(Msg::Transfer(TransferMsg::ExecuteCmd(i)))
-                }
-                _ => Some(Msg::None),
-            },
-            Event::Keyboard(KeyEvent { code: Key::Esc, .. }) => {
-                Some(Msg::Ui(UiMsg::CloseExecPopup))
-            }
-            _ => None,
-        }
-    }
-}
-
 #[derive(MockComponent)]
 pub struct FatalPopup {
     component: Paragraph,
@@ -461,7 +378,7 @@ impl FatalPopup {
                         .modifiers(BorderType::Rounded),
                 )
                 .foreground(color)
-                .text(&[TextSpan::from(text.as_ref())])
+                .text([TextSpan::from(text.as_ref())])
                 .wrap(true),
         }
     }
@@ -497,6 +414,10 @@ impl FileInfoPopup {
         texts
             .add_col(TextSpan::from("Path: "))
             .add_col(TextSpan::new(path.as_str()).fg(Color::Yellow));
+        texts
+            .add_row()
+            .add_col(TextSpan::from("Name: "))
+            .add_col(TextSpan::new(file.name()).fg(Color::Yellow));
         if let Some(filetype) = file.extension() {
             texts
                 .add_row()
@@ -1121,7 +1042,7 @@ impl QuitPopup {
                         .modifiers(BorderType::Rounded),
                 )
                 .foreground(color)
-                .choices(&["Yes", "No"])
+                .choices(["Yes", "No"])
                 .title("Are you sure you want to quit termscp?", Alignment::Center),
         }
     }
@@ -1275,7 +1196,7 @@ impl ReplacePopup {
                         .modifiers(BorderType::Rounded),
                 )
                 .foreground(color)
-                .choices(&["Yes", "No"])
+                .choices(["Yes", "No"])
                 .title(text, Alignment::Center),
         }
     }
@@ -1502,7 +1423,7 @@ impl SortingPopup {
                         .modifiers(BorderType::Rounded),
                 )
                 .foreground(color)
-                .choices(&["Name", "Modify time", "Creation time", "Size"])
+                .choices(["Name", "Modify time", "Creation time", "Size"])
                 .title("Sort files by…", Alignment::Center)
                 .value(match value {
                     FileSorting::CreationTime => 2,
@@ -1554,7 +1475,7 @@ impl StatusBarLocal {
         let file_sorting = file_sorting_label(browser.host_bridge().file_sorting);
         let hidden_files = hidden_files_label(browser.host_bridge().hidden_files_visible());
         Self {
-            component: Span::default().spans(&[
+            component: Span::default().spans([
                 TextSpan::new("File sorting: ").fg(sorting_color),
                 TextSpan::new(file_sorting).fg(sorting_color).reversed(),
                 TextSpan::new(" Hidden files: ").fg(hidden_color),
@@ -1589,7 +1510,7 @@ impl StatusBarRemote {
             false => "OFF",
         };
         Self {
-            component: Span::default().spans(&[
+            component: Span::default().spans([
                 TextSpan::new("File sorting: ").fg(sorting_color),
                 TextSpan::new(file_sorting).fg(sorting_color).reversed(),
                 TextSpan::new(" Hidden files: ").fg(hidden_color),
@@ -1728,7 +1649,7 @@ impl SyncBrowsingMkdirPopup {
                         .modifiers(BorderType::Rounded),
                 )
                 .foreground(color)
-                .choices(&["Yes", "No"])
+                .choices(["Yes", "No"])
                 .title(
                     format!(
                         r#"Sync browsing: directory "{dir_name}" doesn't exist. Do you want to create it?"#
@@ -1802,7 +1723,7 @@ impl WaitPopup {
                         .modifiers(BorderType::Rounded),
                 )
                 .foreground(color)
-                .text(&[TextSpan::from(text.as_ref())])
+                .text([TextSpan::from(text.as_ref())])
                 .wrap(true),
         }
     }
@@ -1830,7 +1751,7 @@ impl WalkdirWaitPopup {
                         .modifiers(BorderType::Rounded),
                 )
                 .foreground(color)
-                .text(&[
+                .text([
                     TextSpan::from(text.as_ref()),
                     TextSpan::from("Press 'CTRL+C' to abort"),
                 ])
@@ -1961,7 +1882,7 @@ impl WatcherPopup {
                         .modifiers(BorderType::Rounded),
                 )
                 .foreground(color)
-                .choices(&["Yes", "No"])
+                .choices(["Yes", "No"])
                 .title(text, Alignment::Center),
         }
     }
