@@ -28,7 +28,7 @@ impl ExplorerFuzzy {
                 .foreground(fg)
                 .highlighted_color(hg)
                 .title(title, Alignment::Left)
-                .rows(files.iter().map(|x| vec![TextSpan::from(x)]).collect()),
+                .rows(files.iter().map(|x| vec![TextSpan::from(*x)]).collect()),
         }
     }
 
@@ -236,7 +236,7 @@ impl ExplorerFind {
                 .foreground(fg)
                 .highlighted_color(hg)
                 .title(title, Alignment::Left)
-                .rows(files.iter().map(|x| vec![TextSpan::from(x)]).collect()),
+                .rows(files.iter().map(|x| vec![TextSpan::from(*x)]).collect()),
         }
     }
 }
@@ -373,7 +373,7 @@ impl ExplorerLocal {
                 .foreground(fg)
                 .highlighted_color(hg)
                 .title(title, Alignment::Left)
-                .rows(files.iter().map(|x| vec![TextSpan::from(x)]).collect())
+                .rows(files.iter().map(|x| vec![TextSpan::from(*x)]).collect())
                 .dot_dot(true),
         }
     }
@@ -547,7 +547,7 @@ impl Component<Msg, NoUserEvent> for ExplorerLocal {
             Event::Keyboard(KeyEvent {
                 code: Key::Char('x'),
                 modifiers: KeyModifiers::NONE,
-            }) => Some(Msg::Ui(UiMsg::ShowExecPopup)),
+            }) => Some(Msg::Ui(UiMsg::ShowTerminal)),
             Event::Keyboard(KeyEvent {
                 code: Key::Char('y'),
                 modifiers: KeyModifiers::NONE,
@@ -587,7 +587,7 @@ impl ExplorerRemote {
                 .foreground(fg)
                 .highlighted_color(hg)
                 .title(title, Alignment::Left)
-                .rows(files.iter().map(|x| vec![TextSpan::from(x)]).collect())
+                .rows(files.iter().map(|x| vec![TextSpan::from(*x)]).collect())
                 .dot_dot(true),
         }
     }
@@ -761,7 +761,7 @@ impl Component<Msg, NoUserEvent> for ExplorerRemote {
             Event::Keyboard(KeyEvent {
                 code: Key::Char('x'),
                 modifiers: KeyModifiers::NONE,
-            }) => Some(Msg::Ui(UiMsg::ShowExecPopup)),
+            }) => Some(Msg::Ui(UiMsg::ShowTerminal)),
             Event::Keyboard(KeyEvent {
                 code: Key::Char('y'),
                 modifiers: KeyModifiers::NONE,
